@@ -5,11 +5,11 @@ import (
 	"strings"
 
 	tea "github.com/charmbracelet/bubbletea"
-	"github.com/git-town/git-town/v17/internal/cli/colors"
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components/list"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/messages"
+	"github.com/git-town/git-town/v18/internal/cli/colors"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components/list"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/messages"
 	"github.com/muesli/termenv"
 )
 
@@ -38,7 +38,7 @@ func Aliases(allAliasableCommands configdomain.AliasableCommands, existingAliase
 	})
 	components.SendInputs(inputs, program)
 	dialogResult, err := program.Run()
-	result := dialogResult.(AliasesModel) //nolint:forcetypeassert
+	result := dialogResult.(AliasesModel)
 	if err != nil || result.Aborted() {
 		return configdomain.Aliases{}, result.Aborted(), err
 	}
