@@ -1,19 +1,18 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
 	"github.com/spf13/cobra"
 )
 
 const (
-	bodyLong  = "body" // long form of the "body" CLI flag
-	bodyShort = "b"    // short form of the "body" CLI flag
+	bodyLong = "body" // long form of the "body" CLI flag
 )
 
 // type-safe access to the CLI arguments of type gitdomain.ProposalBody
-func ProposalBody() (AddFunc, ReadProposalBodyFlagFunc) {
+func ProposalBody(short string) (AddFunc, ReadProposalBodyFlagFunc) {
 	addFlag := func(cmd *cobra.Command) {
-		cmd.Flags().StringP(bodyLong, bodyShort, "", "provide a body for the proposal")
+		cmd.Flags().StringP(bodyLong, short, "", "provide a body for the proposal")
 	}
 	readFlag := func(cmd *cobra.Command) (gitdomain.ProposalBody, error) {
 		value, err := cmd.Flags().GetString(bodyLong)
