@@ -5,27 +5,28 @@ import (
 	"os"
 	"slices"
 
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v17/internal/cli/flags"
-	"github.com/git-town/git-town/v17/internal/cli/print"
-	"github.com/git-town/git-town/v17/internal/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v17/internal/cmd/sync"
-	"github.com/git-town/git-town/v17/internal/config"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/execute"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks/stringslice"
-	"github.com/git-town/git-town/v17/internal/hosting"
-	"github.com/git-town/git-town/v17/internal/hosting/hostingdomain"
-	"github.com/git-town/git-town/v17/internal/messages"
-	"github.com/git-town/git-town/v17/internal/undo/undoconfig"
-	"github.com/git-town/git-town/v17/internal/validate"
-	fullInterpreter "github.com/git-town/git-town/v17/internal/vm/interpreter/full"
-	"github.com/git-town/git-town/v17/internal/vm/opcodes"
-	"github.com/git-town/git-town/v17/internal/vm/program"
-	"github.com/git-town/git-town/v17/internal/vm/runstate"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
-	"github.com/git-town/git-town/v17/pkg/set"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
+	"github.com/git-town/git-town/v18/internal/cli/flags"
+	"github.com/git-town/git-town/v18/internal/cli/print"
+	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v18/internal/cmd/sync"
+	"github.com/git-town/git-town/v18/internal/config"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
+	"github.com/git-town/git-town/v18/internal/hosting"
+	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
+	"github.com/git-town/git-town/v18/internal/messages"
+	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
+	"github.com/git-town/git-town/v18/internal/validate"
+	fullInterpreter "github.com/git-town/git-town/v18/internal/vm/interpreter/full"
+	"github.com/git-town/git-town/v18/internal/vm/opcodes"
+	"github.com/git-town/git-town/v18/internal/vm/optimizer"
+	"github.com/git-town/git-town/v18/internal/vm/program"
+	"github.com/git-town/git-town/v18/internal/vm/runstate"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v18/pkg/set"
 	"github.com/spf13/cobra"
 )
 
@@ -127,7 +128,7 @@ func executeAppend(arg string, detached configdomain.Detached, dryRun configdoma
 type appendFeatureData struct {
 	branchInfos               gitdomain.BranchInfos
 	branchesSnapshot          gitdomain.BranchesSnapshot
-	branchesToSync            []configdomain.BranchToSync
+	branchesToSync            configdomain.BranchesToSync
 	config                    config.ValidatedConfig
 	dialogTestInputs          components.TestInputs
 	dryRun                    configdomain.DryRun
@@ -259,7 +260,7 @@ func appendProgram(data appendFeatureData, finalMessages stringslice.Collector)
 		Ancestors: data.newBranchParentCandidates,
 		Branch:    data.targetBranch,
 	})
-	if data.remotes.HasDev(data.config.NormalConfig.DevRemote) && data.config.NormalConfig.ShouldPushNewBranches() && data.config.NormalConfig.IsOnline() {
+	if data.remotes.HasRemote(data.config.NormalConfig.DevRemote) && data.config.NormalConfig.ShouldPushNewBranches() && data.config.NormalConfig.IsOnline() {
 		prog.Value.Add(&opcodes.BranchTrackingCreate{Branch: data.targetBranch})
 	}
 	prog.Value.Add(&opcodes.LineageParentSetFirstExisting{
@@ -267,21 +268,20 @@ func appendProgram(data appendFeatureData, finalMessages stringslice.Collector)
 		Ancestors: data.newBranchParentCandidates,
 	})
 	if data.prototype.IsTrue() {
-		prog.Value.Add(&opcodes.BranchesPrototypeAdd{Branch: data.targetBranch})
+		prog.Value.Add(&opcodes.BranchTypeOverrideSet{Branch: data.targetBranch, BranchType: configdomain.BranchTypePrototypeBranch})
 	} else {
-		switch data.config.NormalConfig.NewBranchType {
-		case configdomain.BranchTypeContributionBranch:
-			prog.Value.Add(&opcodes.BranchesContributionAdd{Branch: data.targetBranch})
-		case configdomain.BranchTypeFeatureBranch:
-		case configdomain.BranchTypeMainBranch:
-		case configdomain.BranchTypeObservedBranch:
-			prog.Value.Add(&opcodes.BranchesObservedAdd{Branch: data.targetBranch})
-		case configdomain.BranchTypeParkedBranch:
-			prog.Value.Add(&opcodes.BranchesParkedAdd{Branch: data.targetBranch})
-		case configdomain.BranchTypePerennialBranch:
-			prog.Value.Add(&opcodes.BranchesPerennialAdd{Branch: data.targetBranch})
-		case configdomain.BranchTypePrototypeBranch:
-			prog.Value.Add(&opcodes.BranchesPrototypeAdd{Branch: data.targetBranch})
+		if newBranchType, hasNewBranchType := data.config.NormalConfig.NewBranchType.Get(); hasNewBranchType {
+			switch newBranchType {
+			case
+				configdomain.BranchTypeContributionBranch,
+				configdomain.BranchTypeObservedBranch,
+				configdomain.BranchTypeParkedBranch,
+				configdomain.BranchTypePerennialBranch,
+				configdomain.BranchTypePrototypeBranch:
+				prog.Value.Add(&opcodes.BranchTypeOverrideSet{Branch: data.targetBranch, BranchType: newBranchType})
+			case configdomain.BranchTypeFeatureBranch:
+			case configdomain.BranchTypeMainBranch:
+			}
 		}
 	}
 	previousBranchCandidates := []Option[gitdomain.LocalBranchName]{Some(data.initialBranch), data.previousBranch}
@@ -291,5 +291,5 @@ func appendProgram(data appendFeatureData, finalMessages stringslice.Collector)
 		StashOpenChanges:         data.hasOpenChanges,
 		PreviousBranchCandidates: previousBranchCandidates,
 	})
-	return prog.Immutable()
+	return optimizer.Optimize(prog.Immutable())
 }
