@@ -4,13 +4,13 @@ package config
 import (
 	"fmt"
 
-	"github.com/git-town/git-town/v17/internal/cli/flags"
-	"github.com/git-town/git-town/v17/internal/cli/format"
-	"github.com/git-town/git-town/v17/internal/cli/print"
-	"github.com/git-town/git-town/v17/internal/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v17/internal/config"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/execute"
+	"github.com/git-town/git-town/v18/internal/cli/flags"
+	"github.com/git-town/git-town/v18/internal/cli/format"
+	"github.com/git-town/git-town/v18/internal/cli/print"
+	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v18/internal/config"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/execute"
 	"github.com/spf13/cobra"
 )
 
@@ -68,30 +68,34 @@ func printConfig(config config.UnvalidatedConfig) {
 	print.Entry("parked branches", format.StringsSetting((config.NormalConfig.ParkedBranches.Join(", "))))
 	print.Entry("perennial branches", format.StringsSetting((config.NormalConfig.PerennialBranches.Join(", "))))
 	print.Entry("perennial regex", format.OptionalStringerSetting(config.NormalConfig.PerennialRegex))
+	print.Entry("prototype branches", format.StringsSetting((config.NormalConfig.PrototypeBranches.Join(", "))))
 	fmt.Println()
 	print.Header("Configuration")
 	print.Entry("offline", format.Bool(config.NormalConfig.Offline.IsTrue()))
 	fmt.Println()
 	print.Header("Create")
-	print.Entry("new branch type", format.StringsSetting(config.NormalConfig.NewBranchType.String()))
+	print.Entry("new branch type", format.OptionalStringerSetting(config.NormalConfig.NewBranchType))
 	print.Entry("push new branches", format.Bool(config.NormalConfig.ShouldPushNewBranches()))
 	fmt.Println()
 	print.Header("Hosting")
+	print.Entry("development remote", config.NormalConfig.DevRemote.String())
 	print.Entry("hosting platform", format.OptionalStringerSetting(config.NormalConfig.HostingPlatform))
-	print.Entry("hostname", format.OptionalStringerSetting(config.NormalConfig.HostingOriginHostname))
+	print.Entry("origin hostname", format.OptionalStringerSetting(config.NormalConfig.HostingOriginHostname))
+	print.Entry("Bitbucket username", format.OptionalStringerSetting(config.NormalConfig.BitbucketUsername))
+	print.Entry("Bitbucket app password", format.OptionalStringerSetting(config.NormalConfig.BitbucketAppPassword))
+	print.Entry("Gitea token", format.OptionalStringerSetting(config.NormalConfig.GiteaToken))
 	print.Entry("GitHub token", format.OptionalStringerSetting(config.NormalConfig.GitHubToken))
 	print.Entry("GitLab token", format.OptionalStringerSetting(config.NormalConfig.GitLabToken))
-	print.Entry("Gitea token", format.OptionalStringerSetting(config.NormalConfig.GiteaToken))
 	fmt.Println()
 	print.Header("Ship")
-	print.Entry("delete the tracking branch", format.Bool(config.NormalConfig.ShipDeleteTrackingBranch.IsTrue()))
-	print.Entry("strategy", config.NormalConfig.ShipStrategy.String())
+	print.Entry("delete tracking branch", format.Bool(config.NormalConfig.ShipDeleteTrackingBranch.IsTrue()))
+	print.Entry("ship strategy", config.NormalConfig.ShipStrategy.String())
 	fmt.Println()
 	print.Header("Sync")
 	print.Entry("run pre-push hook", format.Bool(bool(config.NormalConfig.PushHook)))
-	print.Entry("sync-feature strategy", config.NormalConfig.SyncFeatureStrategy.String())
-	print.Entry("sync-perennial strategy", config.NormalConfig.SyncPerennialStrategy.String())
-	print.Entry("sync-prototype strategy", config.NormalConfig.SyncPrototypeStrategy.String())
+	print.Entry("feature sync strategy", config.NormalConfig.SyncFeatureStrategy.String())
+	print.Entry("perennial sync strategy", config.NormalConfig.SyncPerennialStrategy.String())
+	print.Entry("prototype sync strategy", config.NormalConfig.SyncPrototypeStrategy.String())
 	print.Entry("sync tags", format.Bool(config.NormalConfig.SyncTags.IsTrue()))
 	print.Entry("sync with upstream", format.Bool(config.NormalConfig.SyncUpstream.IsTrue()))
 	fmt.Println()
