@@ -4,20 +4,20 @@ import (
 	"os"
 	"slices"
 
-	"github.com/git-town/git-town/v17/internal/cli/dialog"
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v17/internal/cli/flags"
-	"github.com/git-town/git-town/v17/internal/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v17/internal/config"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/config/configfile"
-	"github.com/git-town/git-town/v17/internal/config/gitconfig"
-	"github.com/git-town/git-town/v17/internal/execute"
-	"github.com/git-town/git-town/v17/internal/git"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/hosting"
-	configInterpreter "github.com/git-town/git-town/v17/internal/vm/interpreter/config"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/cli/dialog"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
+	"github.com/git-town/git-town/v18/internal/cli/flags"
+	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v18/internal/config"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/config/configfile"
+	"github.com/git-town/git-town/v18/internal/config/gitconfig"
+	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/git"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/hosting"
+	configInterpreter "github.com/git-town/git-town/v18/internal/vm/interpreter/config"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -266,6 +266,9 @@ func loadSetupData(repo execute.OpenRepoResult, verbose configdomain.Verbose) (d
 	if err != nil {
 		return data, exit, err
 	}
+	if len(remotes) == 0 {
+		remotes = gitdomain.Remotes{repo.Git.DefaultRemote(repo.Backend)}
+	}
 	return setupData{
 		config:        repo.UnvalidatedConfig,
 		dialogInputs:  dialogTestInputs,
@@ -370,11 +373,15 @@ func saveBitbucketUsername(oldValue, newValue Option[configdomain.BitbucketUsern
 	return gitCommands.RemoveBitbucketUsername(frontend)
 }
 
-func saveNewBranchType(oldValue, newValue configdomain.BranchType, config config.UnvalidatedConfig) error {
+func saveNewBranchType(oldValue, newValue Option[configdomain.BranchType], config config.UnvalidatedConfig) error {
 	if newValue == oldValue {
 		return nil
 	}
-	return config.NormalConfig.SetNewBranchType(newValue)
+	if value, hasValue := newValue.Get(); hasValue {
+		return config.NormalConfig.SetNewBranchType(value)
+	}
+	config.NormalConfig.RemoveNewBranchType()
+	return nil
 }
 
 func saveDefaultBranchType(oldValue, newValue configdomain.BranchType, config config.UnvalidatedConfig) error {
