@@ -6,28 +6,28 @@ import (
 	"os"
 	"slices"
 
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v17/internal/cli/flags"
-	"github.com/git-town/git-town/v17/internal/cli/print"
-	"github.com/git-town/git-town/v17/internal/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v17/internal/cmd/sync"
-	"github.com/git-town/git-town/v17/internal/config"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/execute"
-	"github.com/git-town/git-town/v17/internal/git"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks"
-	"github.com/git-town/git-town/v17/internal/gohacks/stringslice"
-	"github.com/git-town/git-town/v17/internal/hosting"
-	"github.com/git-town/git-town/v17/internal/hosting/hostingdomain"
-	"github.com/git-town/git-town/v17/internal/messages"
-	"github.com/git-town/git-town/v17/internal/undo/undoconfig"
-	"github.com/git-town/git-town/v17/internal/validate"
-	configInterpreter "github.com/git-town/git-town/v17/internal/vm/interpreter/config"
-	fullInterpreter "github.com/git-town/git-town/v17/internal/vm/interpreter/full"
-	"github.com/git-town/git-town/v17/internal/vm/program"
-	"github.com/git-town/git-town/v17/internal/vm/runstate"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
+	"github.com/git-town/git-town/v18/internal/cli/flags"
+	"github.com/git-town/git-town/v18/internal/cli/print"
+	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v18/internal/cmd/sync"
+	"github.com/git-town/git-town/v18/internal/config"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/git"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks"
+	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
+	"github.com/git-town/git-town/v18/internal/hosting"
+	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
+	"github.com/git-town/git-town/v18/internal/messages"
+	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
+	"github.com/git-town/git-town/v18/internal/validate"
+	configInterpreter "github.com/git-town/git-town/v18/internal/vm/interpreter/config"
+	fullInterpreter "github.com/git-town/git-town/v18/internal/vm/interpreter/full"
+	"github.com/git-town/git-town/v18/internal/vm/program"
+	"github.com/git-town/git-town/v18/internal/vm/runstate"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -306,28 +306,22 @@ func determineHackData(args []string, repo execute.OpenRepoResult, detached conf
 }
 
 func convertToFeatureBranch(args convertToFeatureBranchArgs) error {
-	err := validateConvertToFeatureData(args.makeFeatureData)
-	if err != nil {
-		return err
-	}
 	for branchName, branchType := range args.makeFeatureData.targetBranches {
 		switch branchType {
-		case configdomain.BranchTypeContributionBranch:
-			err = args.config.NormalConfig.RemoveFromContributionBranches(branchName)
-		case configdomain.BranchTypeObservedBranch:
-			err = args.config.NormalConfig.RemoveFromObservedBranches(branchName)
-		case configdomain.BranchTypeParkedBranch:
-			err = args.config.NormalConfig.RemoveFromParkedBranches(branchName)
-		case configdomain.BranchTypePrototypeBranch:
-			err = args.config.NormalConfig.RemoveFromPrototypeBranches(branchName)
 		case
-			configdomain.BranchTypeFeatureBranch,
-			configdomain.BranchTypeMainBranch,
-			configdomain.BranchTypePerennialBranch:
-			panic(fmt.Sprintf("unchecked branch type: %s", branchType))
-		}
-		if err != nil {
-			return err
+			configdomain.BranchTypeContributionBranch,
+			configdomain.BranchTypeObservedBranch,
+			configdomain.BranchTypeParkedBranch,
+			configdomain.BranchTypePrototypeBranch:
+			if err := args.config.NormalConfig.SetBranchTypeOverride(configdomain.BranchTypeFeatureBranch, branchName); err != nil {
+				return err
+			}
+		case configdomain.BranchTypeFeatureBranch:
+			return fmt.Errorf(messages.HackBranchIsAlreadyFeature, branchName)
+		case configdomain.BranchTypeMainBranch:
+			return errors.New(messages.HackCannotFeatureMainBranch)
+		case configdomain.BranchTypePerennialBranch:
+			return fmt.Errorf(messages.HackCannotFeaturePerennialBranch, branchName)
 		}
 		fmt.Printf(messages.HackBranchIsNowFeature, branchName)
 	}
@@ -353,24 +347,3 @@ type convertToFeatureBranchArgs struct {
 	rootDir             gitdomain.RepoRootDir
 	verbose             configdomain.Verbose
 }
-
-func validateConvertToFeatureData(data convertToFeatureData) error {
-	for branchName, branchType := range data.targetBranches {
-		switch branchType {
-		case
-			configdomain.BranchTypeContributionBranch,
-			configdomain.BranchTypeObservedBranch,
-			configdomain.BranchTypeParkedBranch,
-			configdomain.BranchTypePrototypeBranch:
-			return nil
-		case configdomain.BranchTypeFeatureBranch:
-			return fmt.Errorf(messages.HackBranchIsAlreadyFeature, branchName)
-		case configdomain.BranchTypeMainBranch:
-			return errors.New(messages.HackCannotFeatureMainBranch)
-		case configdomain.BranchTypePerennialBranch:
-			return fmt.Errorf(messages.HackCannotFeaturePerennialBranch, branchName)
-		}
-		panic(fmt.Sprintf("unhandled branch type: %s", branchType))
-	}
-	return nil
-}
