@@ -5,26 +5,27 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v17/internal/cli/flags"
-	"github.com/git-town/git-town/v17/internal/cli/print"
-	"github.com/git-town/git-town/v17/internal/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v17/internal/cmd/sync"
-	"github.com/git-town/git-town/v17/internal/config"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/execute"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/hosting"
-	"github.com/git-town/git-town/v17/internal/hosting/hostingdomain"
-	"github.com/git-town/git-town/v17/internal/messages"
-	"github.com/git-town/git-town/v17/internal/undo/undoconfig"
-	"github.com/git-town/git-town/v17/internal/validate"
-	fullInterpreter "github.com/git-town/git-town/v17/internal/vm/interpreter/full"
-	"github.com/git-town/git-town/v17/internal/vm/opcodes"
-	"github.com/git-town/git-town/v17/internal/vm/program"
-	"github.com/git-town/git-town/v17/internal/vm/runstate"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
-	"github.com/git-town/git-town/v17/pkg/set"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
+	"github.com/git-town/git-town/v18/internal/cli/flags"
+	"github.com/git-town/git-town/v18/internal/cli/print"
+	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v18/internal/cmd/sync"
+	"github.com/git-town/git-town/v18/internal/config"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/hosting"
+	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
+	"github.com/git-town/git-town/v18/internal/messages"
+	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
+	"github.com/git-town/git-town/v18/internal/validate"
+	fullInterpreter "github.com/git-town/git-town/v18/internal/vm/interpreter/full"
+	"github.com/git-town/git-town/v18/internal/vm/opcodes"
+	"github.com/git-town/git-town/v18/internal/vm/optimizer"
+	"github.com/git-town/git-town/v18/internal/vm/program"
+	"github.com/git-town/git-town/v18/internal/vm/runstate"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v18/pkg/set"
 	"github.com/spf13/cobra"
 )
 
@@ -79,8 +80,7 @@ func executeMerge(dryRun configdomain.DryRun, verbose configdomain.Verbose) erro
 	if err != nil || exit {
 		return err
 	}
-	err = validateMergeData(data)
-	if err != nil {
+	if err = validateMergeData(data); err != nil {
 		return err
 	}
 	runProgram := mergeProgram(data, dryRun)
@@ -128,11 +128,13 @@ type mergeData struct {
 	initialBranchFirstCommitMessage Option[gitdomain.CommitMessage]
 	initialBranchInfo               gitdomain.BranchInfo
 	initialBranchProposal           Option[hostingdomain.Proposal]
+	initialBranchType               configdomain.BranchType
 	offline                         configdomain.Offline
 	parentBranch                    gitdomain.LocalBranchName
 	parentBranchFirstCommitMessage  Option[gitdomain.CommitMessage]
 	parentBranchInfo                gitdomain.BranchInfo
 	parentBranchProposal            Option[hostingdomain.Proposal]
+	parentBranchType                configdomain.BranchType
 	prefetchBranchesSnapshot        gitdomain.BranchesSnapshot
 	previousBranch                  Option[gitdomain.LocalBranchName]
 	remotes                         gitdomain.Remotes
@@ -221,6 +223,8 @@ func determineMergeData(repo execute.OpenRepoResult, verbose configdomain.Verbos
 	if err != nil {
 		return mergeData{}, false, err
 	}
+	initialBranchType := validatedConfig.BranchType(initialBranch)
+	parentBranchType := validatedConfig.BranchType(parentBranch)
 	parentBranchFirstCommitMessage, err := repo.Git.FirstCommitMessageInBranch(repo.Backend, parentBranch.BranchName(), grandParentBranch.BranchName())
 	if err != nil {
 		return mergeData{}, false, err
@@ -250,11 +254,13 @@ func determineMergeData(repo execute.OpenRepoResult, verbose configdomain.Verbos
 		initialBranchFirstCommitMessage: initialBranchFirstCommitMessage,
 		initialBranchInfo:               *initialBranchInfo,
 		initialBranchProposal:           initialBranchProposal,
+		initialBranchType:               initialBranchType,
 		offline:                         repo.IsOffline,
 		parentBranch:                    parentBranch,
 		parentBranchFirstCommitMessage:  parentBranchFirstCommitMessage,
 		parentBranchInfo:                *parentBranchInfo,
 		parentBranchProposal:            parentBranchProposal,
+		parentBranchType:                parentBranchType,
 		prefetchBranchesSnapshot:        preFetchBranchesSnapshot,
 		previousBranch:                  previousBranch,
 		remotes:                         remotes,
@@ -335,10 +341,16 @@ func mergeProgram(data mergeData, dryRun configdomain.DryRun) program.Program {
 		StashOpenChanges:         data.hasOpenChanges,
 		PreviousBranchCandidates: previousBranchCandidates,
 	})
-	return prog.Immutable()
+	return optimizer.Optimize(prog.Immutable())
 }
 
 func validateMergeData(data mergeData) error {
+	if err := verifyBranchType(data.initialBranchType); err != nil {
+		return err
+	}
+	if err := verifyBranchType(data.parentBranchType); err != nil {
+		return err
+	}
 	// ensure parent isn't deleted at remote
 	parentInfo, hasParent := data.branchesSnapshot.Branches.FindLocalOrRemote(data.parentBranch, data.config.NormalConfig.DevRemote).Get()
 	if !hasParent {
@@ -361,3 +373,19 @@ func validateMergeData(data mergeData) error {
 	// ensure parent branch has only one child
 	return nil
 }
+
+func verifyBranchType(branchType configdomain.BranchType) error {
+	switch branchType {
+	case
+		configdomain.BranchTypeContributionBranch,
+		configdomain.BranchTypeMainBranch,
+		configdomain.BranchTypeObservedBranch,
+		configdomain.BranchTypePerennialBranch:
+		return fmt.Errorf(messages.MergeWrongBranchType, branchType)
+	case
+		configdomain.BranchTypeFeatureBranch,
+		configdomain.BranchTypeParkedBranch,
+		configdomain.BranchTypePrototypeBranch:
+	}
+	return nil
+}
