@@ -6,27 +6,28 @@ import (
 	"io"
 	"os"
 
-	"github.com/git-town/git-town/v17/internal/browser"
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v17/internal/cli/flags"
-	"github.com/git-town/git-town/v17/internal/cli/print"
-	"github.com/git-town/git-town/v17/internal/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v17/internal/cmd/sync"
-	"github.com/git-town/git-town/v17/internal/config"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/execute"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/hosting"
-	"github.com/git-town/git-town/v17/internal/hosting/hostingdomain"
-	"github.com/git-town/git-town/v17/internal/messages"
-	"github.com/git-town/git-town/v17/internal/undo/undoconfig"
-	"github.com/git-town/git-town/v17/internal/validate"
-	fullInterpreter "github.com/git-town/git-town/v17/internal/vm/interpreter/full"
-	"github.com/git-town/git-town/v17/internal/vm/opcodes"
-	"github.com/git-town/git-town/v17/internal/vm/program"
-	"github.com/git-town/git-town/v17/internal/vm/runstate"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
-	"github.com/git-town/git-town/v17/pkg/set"
+	"github.com/git-town/git-town/v18/internal/browser"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
+	"github.com/git-town/git-town/v18/internal/cli/flags"
+	"github.com/git-town/git-town/v18/internal/cli/print"
+	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v18/internal/cmd/sync"
+	"github.com/git-town/git-town/v18/internal/config"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/hosting"
+	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
+	"github.com/git-town/git-town/v18/internal/messages"
+	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
+	"github.com/git-town/git-town/v18/internal/validate"
+	fullInterpreter "github.com/git-town/git-town/v18/internal/vm/interpreter/full"
+	"github.com/git-town/git-town/v18/internal/vm/opcodes"
+	"github.com/git-town/git-town/v18/internal/vm/optimizer"
+	"github.com/git-town/git-town/v18/internal/vm/program"
+	"github.com/git-town/git-town/v18/internal/vm/runstate"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v18/pkg/set"
 	"github.com/spf13/cobra"
 )
 
@@ -42,7 +43,7 @@ The form is pre-populated for the current branch so that the proposal only shows
 Supported only for repositories hosted on GitHub, GitLab, Gitea and Bitbucket. When using self-hosted versions this command needs to be configured with "git config %s <driver>" where driver is "github", "gitlab", "gitea", or "bitbucket". When using SSH identities, this command needs to be configured with "git config %s <hostname>" where hostname matches what is in your ssh config file.`
 
 func proposeCommand() *cobra.Command {
-	addBodyFlag, readBodyFlag := flags.ProposalBody()
+	addBodyFlag, readBodyFlag := flags.ProposalBody("b")
 	addBodyFileFlag, readBodyFileFlag := flags.ProposalBodyFile()
 	addDetachedFlag, readDetachedFlag := flags.Detached()
 	addDryRunFlag, readDryRunFlag := flags.DryRun()
@@ -150,7 +151,7 @@ type proposeData struct {
 	branchToPropose     gitdomain.LocalBranchName
 	branchTypeToPropose configdomain.BranchType
 	branchesSnapshot    gitdomain.BranchesSnapshot
-	branchesToSync      []configdomain.BranchToSync
+	branchesToSync      configdomain.BranchesToSync
 	config              config.ValidatedConfig
 	connector           Option[hostingdomain.Connector]
 	dialogTestInputs    components.TestInputs
@@ -317,7 +318,8 @@ func proposeProgram(repo execute.OpenRepoResult, data proposeData) program.Progr
 		PushBranches:        true,
 	})
 	if data.branchTypeToPropose == configdomain.BranchTypePrototypeBranch {
-		prog.Value.Add(&opcodes.BranchesPrototypeRemove{Branch: data.branchToPropose})
+		prog.Value.Add(&opcodes.BranchTypeOverrideRemove{Branch: data.branchToPropose})
+		repo.FinalMessages.Add(fmt.Sprintf(messages.PrototypeRemoved, data.branchToPropose))
 	}
 	prog.Value.Add(&opcodes.PushCurrentBranchIfLocal{
 		CurrentBranch: data.branchToPropose,
@@ -340,7 +342,7 @@ func proposeProgram(repo execute.OpenRepoResult, data proposeData) program.Progr
 		ProposalBody:  data.proposalBody,
 		ProposalTitle: data.proposalTitle,
 	})
-	return prog.Immutable()
+	return optimizer.Optimize(prog.Immutable())
 }
 
 func validateBranchTypeToPropose(branchType configdomain.BranchType) error {
