@@ -4,28 +4,28 @@ import (
 	"errors"
 	"fmt"
 	"os"
-	"slices"
 
-	"github.com/git-town/git-town/v17/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v17/internal/cli/flags"
-	"github.com/git-town/git-town/v17/internal/cli/print"
-	"github.com/git-town/git-town/v17/internal/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v17/internal/cmd/ship"
-	"github.com/git-town/git-town/v17/internal/config"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/execute"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks/stringslice"
-	"github.com/git-town/git-town/v17/internal/hosting"
-	"github.com/git-town/git-town/v17/internal/hosting/hostingdomain"
-	"github.com/git-town/git-town/v17/internal/messages"
-	"github.com/git-town/git-town/v17/internal/undo/undoconfig"
-	"github.com/git-town/git-town/v17/internal/validate"
-	fullInterpreter "github.com/git-town/git-town/v17/internal/vm/interpreter/full"
-	"github.com/git-town/git-town/v17/internal/vm/opcodes"
-	"github.com/git-town/git-town/v17/internal/vm/program"
-	"github.com/git-town/git-town/v17/internal/vm/runstate"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/cli/dialog/components"
+	"github.com/git-town/git-town/v18/internal/cli/flags"
+	"github.com/git-town/git-town/v18/internal/cli/print"
+	"github.com/git-town/git-town/v18/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v18/internal/cmd/ship"
+	"github.com/git-town/git-town/v18/internal/config"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/execute"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
+	"github.com/git-town/git-town/v18/internal/hosting"
+	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
+	"github.com/git-town/git-town/v18/internal/messages"
+	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
+	"github.com/git-town/git-town/v18/internal/validate"
+	fullInterpreter "github.com/git-town/git-town/v18/internal/vm/interpreter/full"
+	"github.com/git-town/git-town/v18/internal/vm/opcodes"
+	"github.com/git-town/git-town/v18/internal/vm/optimizer"
+	"github.com/git-town/git-town/v18/internal/vm/program"
+	"github.com/git-town/git-town/v18/internal/vm/runstate"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/spf13/cobra"
 )
 
@@ -217,7 +217,7 @@ func determineRenameData(args []string, force configdomain.Force, repo execute.O
 		return data, false, errors.New(messages.RenameMainBranch)
 	}
 	if force.IsFalse() {
-		if validatedConfig.NormalConfig.IsPerennialBranch(oldBranchName) {
+		if validatedConfig.BranchType(oldBranchName) == configdomain.BranchTypePerennialBranch {
 			return data, false, fmt.Errorf(messages.RenamePerennialBranchWarning, oldBranchName)
 		}
 	}
@@ -236,7 +236,10 @@ func determineRenameData(args []string, force configdomain.Force, repo execute.O
 	parentOpt := validatedConfig.NormalConfig.Lineage.Parent(initialBranch)
 	lineageBranches := validatedConfig.NormalConfig.Lineage.BranchNames()
 	_, nonExistingBranches := branchesSnapshot.Branches.Select(repo.UnvalidatedConfig.NormalConfig.DevRemote, lineageBranches...)
-	proposalOpt := ship.FindProposal(connectorOpt, initialBranch, parentOpt)
+	proposalOpt := None[hostingdomain.Proposal]()
+	if !repo.IsOffline {
+		proposalOpt = ship.FindProposal(connectorOpt, initialBranch, parentOpt)
+	}
 	proposalsOfChildBranches := ship.LoadProposalsOfChildBranches(ship.LoadProposalsOfChildBranchesArgs{
 		ConnectorOpt:               connectorOpt,
 		Lineage:                    validatedConfig.NormalConfig.Lineage,
@@ -263,70 +266,63 @@ func determineRenameData(args []string, force configdomain.Force, repo execute.O
 }
 
 func renameProgram(data renameData, finalMessages stringslice.Collector) program.Program {
-	result := NewMutable(&program.Program{})
+	prog := NewMutable(&program.Program{})
 	data.config.CleanupLineage(data.branchesSnapshot.Branches, data.nonExistingBranches, finalMessages)
 	oldLocalBranch, hasOldLocalBranch := data.oldBranch.LocalName.Get()
 	if !hasOldLocalBranch {
-		return result.Immutable()
+		return prog.Immutable()
 	}
-	result.Value.Add(&opcodes.BranchLocalRename{OldName: oldLocalBranch, NewName: data.newBranch})
+	prog.Value.Add(&opcodes.BranchLocalRename{OldName: oldLocalBranch, NewName: data.newBranch})
 	if data.initialBranch == oldLocalBranch {
-		result.Value.Add(&opcodes.CheckoutIfNeeded{Branch: data.newBranch})
+		prog.Value.Add(&opcodes.CheckoutIfNeeded{Branch: data.newBranch})
 	}
 	if !data.dryRun {
-		if data.config.NormalConfig.IsPerennialBranch(data.initialBranch) {
-			result.Value.Add(&opcodes.BranchesPerennialRemove{Branch: oldLocalBranch})
-			result.Value.Add(&opcodes.BranchesPerennialAdd{Branch: data.newBranch})
-		}
-		if slices.Contains(data.config.NormalConfig.PrototypeBranches, data.initialBranch) {
-			result.Value.Add(&opcodes.BranchesPrototypeRemove{Branch: oldLocalBranch})
-			result.Value.Add(&opcodes.BranchesPrototypeAdd{Branch: data.newBranch})
-		}
-		if slices.Contains(data.config.NormalConfig.ObservedBranches, data.initialBranch) {
-			result.Value.Add(&opcodes.BranchesObservedRemove{Branch: oldLocalBranch})
-			result.Value.Add(&opcodes.BranchesObservedAdd{Branch: data.newBranch})
-		}
-		if slices.Contains(data.config.NormalConfig.ContributionBranches, data.initialBranch) {
-			result.Value.Add(&opcodes.BranchesContributionRemove{Branch: oldLocalBranch})
-			result.Value.Add(&opcodes.BranchesContributionAdd{Branch: data.newBranch})
-		}
-		if slices.Contains(data.config.NormalConfig.ParkedBranches, data.initialBranch) {
-			result.Value.Add(&opcodes.BranchesParkedRemove{Branch: oldLocalBranch})
-			result.Value.Add(&opcodes.BranchesParkedAdd{Branch: data.newBranch})
+		if override, hasBranchTypeOverride := data.config.NormalConfig.BranchTypeOverrides[oldLocalBranch]; hasBranchTypeOverride {
+			prog.Value.Add(
+				&opcodes.ConfigSet{
+					Key:   configdomain.NewBranchTypeOverrideKeyForBranch(data.newBranch).Key,
+					Scope: configdomain.ConfigScopeLocal,
+					Value: override.String(),
+				},
+				&opcodes.ConfigRemove{
+					Key:   configdomain.NewBranchTypeOverrideKeyForBranch(oldLocalBranch).Key,
+					Scope: configdomain.ConfigScopeLocal,
+				},
+			)
 		}
 		if parentBranch, hasParent := data.config.NormalConfig.Lineage.Parent(oldLocalBranch).Get(); hasParent {
-			result.Value.Add(&opcodes.LineageParentSet{Branch: data.newBranch, Parent: parentBranch})
+			prog.Value.Add(&opcodes.LineageParentSet{Branch: data.newBranch, Parent: parentBranch})
 		}
-		result.Value.Add(&opcodes.LineageParentRemove{Branch: oldLocalBranch})
+		prog.Value.Add(&opcodes.LineageParentRemove{Branch: oldLocalBranch})
 	}
 	for _, child := range data.config.NormalConfig.Lineage.Children(oldLocalBranch) {
-		result.Value.Add(&opcodes.LineageParentSet{Branch: child, Parent: data.newBranch})
+		prog.Value.Add(&opcodes.LineageParentSet{Branch: child, Parent: data.newBranch})
 	}
 	if oldTrackingBranch, hasOldTrackingBranch := data.oldBranch.RemoteName.Get(); hasOldTrackingBranch {
 		if data.oldBranch.HasTrackingBranch() && data.config.NormalConfig.IsOnline() {
-			result.Value.Add(&opcodes.BranchTrackingCreate{Branch: data.newBranch})
-			updateChildBranchProposalsToBranch(result.Value, data.proposalsOfChildBranches, data.newBranch)
+			prog.Value.Add(&opcodes.BranchTrackingCreate{Branch: data.newBranch})
+			updateChildBranchProposalsToBranch(prog.Value, data.proposalsOfChildBranches, data.newBranch)
 			proposal, hasProposal := data.proposal.Get()
 			connector, hasConnector := data.connector.Get()
 			connectorCanUpdateProposalSource := hasConnector && connector.UpdateProposalSourceFn().IsSome()
 			if hasProposal && hasConnector && connectorCanUpdateProposalSource {
-				result.Value.Add(&opcodes.ProposalUpdateSource{
+				prog.Value.Add(&opcodes.ProposalUpdateSource{
 					NewBranch:      data.newBranch,
 					OldBranch:      data.oldBranch.LocalBranchName(),
 					ProposalNumber: proposal.Number,
 				})
 			}
-			result.Value.Add(&opcodes.BranchTrackingDelete{Branch: oldTrackingBranch})
+			prog.Value.Add(&opcodes.BranchTrackingDelete{Branch: oldTrackingBranch})
 		}
 	}
 	previousBranchCandidates := []Option[gitdomain.LocalBranchName]{Some(data.newBranch), data.previousBranch}
-	cmdhelpers.Wrap(result, cmdhelpers.WrapOptions{
+	cmdhelpers.Wrap(prog, cmdhelpers.WrapOptions{
 		DryRun:                   data.dryRun,
 		RunInGitRoot:             false,
 		StashOpenChanges:         false,
 		PreviousBranchCandidates: previousBranchCandidates,
 	})
-	return result.Immutable()
+	return optimizer.Optimize(prog.Immutable())
 }
 
 func updateChildBranchProposalsToBranch(prog *program.Program, proposals []hostingdomain.Proposal, target gitdomain.LocalBranchName) {
