@@ -1,13 +1,13 @@
 package sync
 
 import (
-	"github.com/git-town/git-town/v17/internal/config"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/vm/opcodes"
-	"github.com/git-town/git-town/v17/internal/vm/program"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
-	"github.com/git-town/git-town/v17/pkg/set"
+	"github.com/git-town/git-town/v18/internal/config"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/vm/opcodes"
+	"github.com/git-town/git-town/v18/internal/vm/program"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v18/pkg/set"
 )
 
 // BranchProgram syncs the given branch.
@@ -63,13 +63,13 @@ type BranchProgramArgs struct {
 
 // LocalBranchProgram provides the program to sync a local branch.
 func LocalBranchProgram(localName gitdomain.LocalBranchName, branchInfo gitdomain.BranchInfo, originalParentName Option[gitdomain.LocalBranchName], originalParentSHA Option[gitdomain.SHA], firstCommitMessage Option[gitdomain.CommitMessage], args BranchProgramArgs) {
-	isMainOrPerennialBranch := args.Config.IsMainOrPerennialBranch(localName)
-	if isMainOrPerennialBranch && !args.Remotes.HasDev(args.Config.NormalConfig.DevRemote) {
+	branchType := args.Config.BranchType(localName)
+	isMainOrPerennialBranch := branchType == configdomain.BranchTypeMainBranch || branchType == configdomain.BranchTypePerennialBranch
+	if isMainOrPerennialBranch && !args.Remotes.HasRemote(args.Config.NormalConfig.DevRemote) {
 		// perennial branch but no remote --> this branch cannot be synced
 		return
 	}
 	args.Program.Value.Add(&opcodes.CheckoutIfNeeded{Branch: localName})
-	branchType := args.Config.BranchType(localName)
 	switch branchType {
 	case configdomain.BranchTypeFeatureBranch:
 		FeatureBranchProgram(args.Config.NormalConfig.SyncFeatureStrategy.SyncStrategy(), featureBranchArgs{
@@ -82,9 +82,7 @@ func LocalBranchProgram(localName gitdomain.LocalBranchName, branchInfo gitdomai
 			pushBranches:       args.PushBranches,
 			trackingBranchName: branchInfo.RemoteName,
 		})
-	case
-		configdomain.BranchTypePerennialBranch,
-		configdomain.BranchTypeMainBranch:
+	case configdomain.BranchTypePerennialBranch, configdomain.BranchTypeMainBranch:
 		PerennialBranchProgram(branchInfo, args)
 	case configdomain.BranchTypeParkedBranch:
 		ParkedBranchProgram(args.Config.NormalConfig.SyncFeatureStrategy.SyncStrategy(), args.InitialBranch, featureBranchArgs{
@@ -100,7 +98,7 @@ func LocalBranchProgram(localName gitdomain.LocalBranchName, branchInfo gitdomai
 	case configdomain.BranchTypeContributionBranch:
 		ContributionBranchProgram(args.Program, branchInfo)
 	case configdomain.BranchTypeObservedBranch:
-		ObservedBranchProgram(branchInfo.RemoteName, args.Program)
+		ObservedBranchProgram(branchInfo, args.Program)
 	case configdomain.BranchTypePrototypeBranch:
 		FeatureBranchProgram(args.Config.NormalConfig.SyncPrototypeStrategy.SyncStrategy(), featureBranchArgs{
 			firstCommitMessage: firstCommitMessage,
@@ -109,14 +107,19 @@ func LocalBranchProgram(localName gitdomain.LocalBranchName, branchInfo gitdomai
 			originalParentName: originalParentName,
 			originalParentSHA:  originalParentSHA,
 			program:            args.Program,
-			pushBranches:       false,
+			pushBranches:       configdomain.PushBranches(branchInfo.HasTrackingBranch()),
 			trackingBranchName: branchInfo.RemoteName,
 		})
 	}
-	if args.PushBranches.IsTrue() && args.Remotes.HasDev(args.Config.NormalConfig.DevRemote) && args.Config.NormalConfig.IsOnline() && branchType.ShouldPush(localName == args.InitialBranch) {
+	if args.PushBranches.IsTrue() && args.Remotes.HasRemote(args.Config.NormalConfig.DevRemote) && args.Config.NormalConfig.IsOnline() && branchType.ShouldPush(localName == args.InitialBranch) {
+		isMainBranch := branchType == configdomain.BranchTypeMainBranch
 		switch {
 		case !branchInfo.HasTrackingBranch():
 			args.Program.Value.Add(&opcodes.BranchTrackingCreate{Branch: localName})
+		case isMainBranch && args.Remotes.HasUpstream() && args.Config.NormalConfig.SyncUpstream.IsTrue():
+			args.Program.Value.Add(&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: localName})
+		case isMainOrPerennialBranch && !shouldPushPerennialBranch(branchInfo.SyncStatus):
+			// don't push if its a perennial branch that doesn't need pushing
 		case isMainOrPerennialBranch:
 			args.Program.Value.Add(&opcodes.PushCurrentBranchIfNeeded{CurrentBranch: localName})
 		default:
@@ -197,6 +200,23 @@ type RemoveAncestorCommitsArgs struct {
 	RebaseOnto        gitdomain.LocalBranchName
 }
 
+func shouldPushPerennialBranch(syncStatus gitdomain.SyncStatus) bool {
+	switch syncStatus {
+	case
+		gitdomain.SyncStatusAhead,
+		gitdomain.SyncStatusBehind,
+		gitdomain.SyncStatusLocalOnly,
+		gitdomain.SyncStatusNotInSync:
+		return true
+	case
+		gitdomain.SyncStatusDeletedAtRemote,
+		gitdomain.SyncStatusOtherWorktree,
+		gitdomain.SyncStatusRemoteOnly,
+		gitdomain.SyncStatusUpToDate:
+	}
+	return false
+}
+
 // updateCurrentPerennialBranchOpcode provides the opcode to update the current perennial branch with changes from the given other branch.
 func updateCurrentPerennialBranchOpcode(prog Mutable[program.Program], otherBranch gitdomain.RemoteBranchName, strategy configdomain.SyncPerennialStrategy) {
 	switch strategy {
@@ -204,5 +224,7 @@ func updateCurrentPerennialBranchOpcode(prog Mutable[program.Program], otherBran
 		prog.Value.Add(&opcodes.Merge{Branch: otherBranch.BranchName()})
 	case configdomain.SyncPerennialStrategyRebase:
 		prog.Value.Add(&opcodes.RebaseBranch{Branch: otherBranch.BranchName()})
+	case configdomain.SyncPerennialStrategyFFOnly:
+		prog.Value.Add(&opcodes.MergeFastForward{Branch: otherBranch.BranchName()})
 	}
 }
