@@ -1,12 +1,12 @@
 package sync
 
 import (
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/vm/opcodes"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/vm/opcodes"
 )
 
 // BranchesProgram syncs all given branches.
-func BranchesProgram(branchesToSync []configdomain.BranchToSync, args BranchProgramArgs) {
+func BranchesProgram(branchesToSync configdomain.BranchesToSync, args BranchProgramArgs) {
 	for _, branchToSync := range branchesToSync {
 		if localBranchName, hasLocalBranch := branchToSync.BranchInfo.LocalName.Get(); hasLocalBranch {
 			BranchProgram(localBranchName, branchToSync.BranchInfo, branchToSync.FirstCommitMessage, args)
