@@ -1,11 +1,11 @@
 package sync
 
 import (
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/vm/opcodes"
-	"github.com/git-town/git-town/v17/internal/vm/program"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/vm/opcodes"
+	"github.com/git-town/git-town/v18/internal/vm/program"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 )
 
 // FeatureBranchProgram adds the opcodes to sync the feature branch with the given name.
@@ -49,6 +49,9 @@ func syncFeatureParentBranch(syncStrategy configdomain.SyncStrategy, args featur
 			OriginalParentName: args.originalParentName,
 			OriginalParentSHA:  args.originalParentSHA,
 		})
+	case configdomain.SyncStrategyFFOnly:
+		// The ff-only strategy does not sync with the parent branch.
+		// It is intended for perennial branches only.
 	}
 }
 
@@ -73,6 +76,10 @@ func FeatureTrackingBranchProgram(trackingBranch gitdomain.RemoteBranchName, syn
 		if args.Offline.IsFalse() {
 			args.Program.Value.Add(&opcodes.RebaseTrackingBranch{RemoteBranch: trackingBranch, PushBranches: args.PushBranches})
 		}
+	case configdomain.SyncStrategyFFOnly:
+		if args.Offline.IsFalse() {
+			args.Program.Value.Add(&opcodes.MergeFastForward{Branch: trackingBranch.BranchName()})
+		}
 	}
 }
 
