@@ -3,9 +3,9 @@ package configdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
@@ -97,7 +97,7 @@ func TestLineage(t *testing.T) {
 		t.Run("only root exists", func(t *testing.T) {
 			t.Parallel()
 			lineage := configdomain.Lineage{}
-			have := lineage.BranchLineageWithoutRoot(main)
+			have := lineage.BranchLineageWithoutRoot(main, gitdomain.LocalBranchNames{main})
 			want := gitdomain.LocalBranchNames{}
 			must.Eq(t, want, have)
 		})
@@ -106,7 +106,7 @@ func TestLineage(t *testing.T) {
 			lineage := configdomain.NewLineageWith(configdomain.LineageData{
 				one: main,
 			})
-			have := lineage.BranchLineageWithoutRoot(one)
+			have := lineage.BranchLineageWithoutRoot(one, gitdomain.LocalBranchNames{main})
 			want := gitdomain.LocalBranchNames{one}
 			must.Eq(t, want, have)
 		})
@@ -119,20 +119,27 @@ func TestLineage(t *testing.T) {
 			want := gitdomain.LocalBranchNames{one, two}
 			t.Run("given root", func(t *testing.T) {
 				t.Parallel()
-				have := lineage.BranchLineageWithoutRoot(main)
+				have := lineage.BranchLineageWithoutRoot(main, gitdomain.LocalBranchNames{main})
 				must.Eq(t, want, have)
 			})
 			t.Run("given middle branch", func(t *testing.T) {
 				t.Parallel()
-				have := lineage.BranchLineageWithoutRoot(one)
+				have := lineage.BranchLineageWithoutRoot(one, gitdomain.LocalBranchNames{main})
 				must.Eq(t, want, have)
 			})
 			t.Run("given leaf branch", func(t *testing.T) {
 				t.Parallel()
-				have := lineage.BranchLineageWithoutRoot(two)
+				have := lineage.BranchLineageWithoutRoot(two, gitdomain.LocalBranchNames{main})
 				must.Eq(t, want, have)
 			})
 		})
+		t.Run("branch without an ancestor", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.Lineage{}
+			have := lineage.BranchLineageWithoutRoot(one, gitdomain.LocalBranchNames{main})
+			want := gitdomain.LocalBranchNames{one}
+			must.Eq(t, want, have)
+		})
 	})
 
 	t.Run("BranchNames", func(t *testing.T) {
@@ -147,27 +154,6 @@ func TestLineage(t *testing.T) {
 		must.Eq(t, want, have)
 	})
 
-	t.Run("BranchesWithParents", func(t *testing.T) {
-		t.Parallel()
-		t.Run("populated", func(t *testing.T) {
-			t.Parallel()
-			lineage := configdomain.NewLineageWith(configdomain.LineageData{
-				"branch-1": "branch-2",
-				"branch-3": "branch-4",
-			})
-			have := lineage.BranchesWithParents()
-			want := gitdomain.NewLocalBranchNames("branch-1", "branch-3")
-			must.Eq(t, want, have)
-		})
-		t.Run("empty", func(t *testing.T) {
-			t.Parallel()
-			lineage := configdomain.NewLineage()
-			have := lineage.BranchesWithParents()
-			want := gitdomain.LocalBranchNames{}
-			must.Eq(t, want, have)
-		})
-	})
-
 	t.Run("BranchesAndAncestors", func(t *testing.T) {
 		t.Parallel()
 		t.Run("deep lineage, multiple branches", func(t *testing.T) {
@@ -226,6 +212,27 @@ func TestLineage(t *testing.T) {
 		})
 	})
 
+	t.Run("BranchesWithParents", func(t *testing.T) {
+		t.Parallel()
+		t.Run("populated", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.NewLineageWith(configdomain.LineageData{
+				"branch-1": "branch-2",
+				"branch-3": "branch-4",
+			})
+			have := lineage.BranchesWithParents()
+			want := gitdomain.NewLocalBranchNames("branch-1", "branch-3")
+			must.Eq(t, want, have)
+		})
+		t.Run("empty", func(t *testing.T) {
+			t.Parallel()
+			lineage := configdomain.NewLineage()
+			have := lineage.BranchesWithParents()
+			want := gitdomain.LocalBranchNames(nil)
+			must.Eq(t, want, have)
+		})
+	})
+
 	t.Run("Children", func(t *testing.T) {
 		t.Parallel()
 		t.Run("provides all children of the given branch, ordered alphabetically", func(t *testing.T) {
