@@ -7,11 +7,11 @@ import (
 	"path/filepath"
 
 	"github.com/BurntSushi/toml"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks/stringslice"
-	"github.com/git-town/git-town/v17/internal/messages"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
+	"github.com/git-town/git-town/v18/internal/messages"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 )
 
 // Decode converts the given config file TOML source into Go data.
@@ -21,8 +21,8 @@ func Decode(text string) (*Data, error) {
 	return &result, err
 }
 
-func Load(rootDir gitdomain.RepoRootDir, finalMessages stringslice.Collector) (Option[configdomain.PartialConfig], error) {
-	configPath := filepath.Join(rootDir.String(), FileName)
+func Load(rootDir gitdomain.RepoRootDir, fileName string, finalMessages stringslice.Collector) (Option[configdomain.PartialConfig], error) {
+	configPath := filepath.Join(rootDir.String(), fileName)
 	file, err := os.Open(configPath)
 	if err != nil {
 		return None[configdomain.PartialConfig](), nil
@@ -30,11 +30,11 @@ func Load(rootDir gitdomain.RepoRootDir, finalMessages stringslice.Collector) (O
 	defer file.Close()
 	bytes, err := io.ReadAll(file)
 	if err != nil {
-		return None[configdomain.PartialConfig](), fmt.Errorf(messages.ConfigFileCannotRead, ".git-branches.yml", err)
+		return None[configdomain.PartialConfig](), fmt.Errorf(messages.ConfigFileCannotRead, fileName, err)
 	}
 	configFileData, err := Decode(string(bytes))
 	if err != nil {
-		return None[configdomain.PartialConfig](), fmt.Errorf(messages.ConfigFileInvalidContent, ".git-branches.yml", err)
+		return None[configdomain.PartialConfig](), fmt.Errorf(messages.ConfigFileInvalidContent, fileName, err)
 	}
 	result, err := Validate(*configFileData, finalMessages)
 	return Some(result), err
@@ -219,6 +219,7 @@ func Validate(data Data, finalMessages stringslice.Collector) (configdomain.Part
 		Aliases:                  map[configdomain.AliasableCommand]string{},
 		BitbucketAppPassword:     None[configdomain.BitbucketAppPassword](),
 		BitbucketUsername:        None[configdomain.BitbucketUsername](),
+		BranchTypeOverrides:      configdomain.BranchTypeOverrides{},
 		ContributionBranches:     gitdomain.LocalBranchNames{},
 		ContributionRegex:        contributionRegex,
 		DefaultBranchType:        defaultBranchType,
