@@ -7,19 +7,19 @@ import (
 	"os/exec"
 	"runtime"
 
-	"github.com/git-town/git-town/v17/internal/config"
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/config/configfile"
-	"github.com/git-town/git-town/v17/internal/config/gitconfig"
-	"github.com/git-town/git-town/v17/internal/git"
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks"
-	"github.com/git-town/git-town/v17/internal/gohacks/cache"
-	"github.com/git-town/git-town/v17/internal/gohacks/stringslice"
-	"github.com/git-town/git-town/v17/internal/messages"
-	"github.com/git-town/git-town/v17/internal/subshell"
-	"github.com/git-town/git-town/v17/internal/undo/undoconfig"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/config"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/config/configfile"
+	"github.com/git-town/git-town/v18/internal/config/gitconfig"
+	"github.com/git-town/git-town/v18/internal/git"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks"
+	"github.com/git-town/git-town/v18/internal/gohacks/cache"
+	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
+	"github.com/git-town/git-town/v18/internal/messages"
+	"github.com/git-town/git-town/v18/internal/subshell"
+	"github.com/git-town/git-town/v18/internal/undo/undoconfig"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 )
 
 func OpenRepo(args OpenRepoArgs) (OpenRepoResult, error) {
@@ -43,8 +43,8 @@ func OpenRepo(args OpenRepoArgs) (OpenRepoResult, error) {
 		Verbose:         args.Verbose,
 	}
 	gitCommands := git.Commands{
-		CurrentBranchCache: &cache.LocalBranchWithPrevious{},
-		RemotesCache:       &cache.Remotes{},
+		CurrentBranchCache: &cache.WithPrevious[gitdomain.LocalBranchName]{},
+		RemotesCache:       &cache.Cache[gitdomain.Remotes]{},
 	}
 	gitVersion, err := gitCommands.Version(backendRunner)
 	if err != nil {
@@ -74,10 +74,16 @@ func OpenRepo(args OpenRepoArgs) (OpenRepoResult, error) {
 		Local:  localSnapshot,
 	}
 	finalMessages := stringslice.NewCollector()
-	configFile, err := configfile.Load(rootDir, finalMessages)
+	configFile, err := configfile.Load(rootDir, configfile.FileName, finalMessages)
 	if err != nil {
 		return emptyOpenRepoResult(), err
 	}
+	if configFile.IsNone() {
+		configFile, err = configfile.Load(rootDir, configfile.AlternativeFileName, finalMessages)
+		if err != nil {
+			return emptyOpenRepoResult(), err
+		}
+	}
 	unvalidatedConfig := config.NewUnvalidatedConfig(config.NewUnvalidatedConfigArgs{
 		Access:        configGitAccess,
 		ConfigFile:    configFile,
