@@ -3,7 +3,7 @@ package gitdomain
 import (
 	"strings"
 
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 )
 
 // Remote represents a Git remote.
@@ -23,5 +23,6 @@ func (self Remote) String() string {
 }
 
 const (
-	RemoteUpstream = Remote("upstream")
+	RemoteOrigin   Remote = "origin"
+	RemoteUpstream Remote = "upstream"
 )
