@@ -3,10 +3,10 @@ package hosting_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/git/giturl"
-	"github.com/git-town/git-town/v17/internal/hosting"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/git/giturl"
+	"github.com/git-town/git-town/v18/internal/hosting"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
@@ -22,42 +22,6 @@ func TestDetect(t *testing.T) {
 		must.Eq(t, want, have)
 	})
 
-	t.Run("custom URL, override to BitBucket", func(t *testing.T) {
-		t.Parallel()
-		url, has := giturl.Parse("username@custom.org:git-town/docs.git").Get()
-		must.True(t, has)
-		have := hosting.Detect(url, Some(configdomain.HostingPlatformBitbucket))
-		want := Some(configdomain.HostingPlatformBitbucket)
-		must.Eq(t, want, have)
-	})
-
-	t.Run("custom URL, override to BitBucket Datacenter", func(t *testing.T) {
-		t.Parallel()
-		url, has := giturl.Parse("username@custom.org:git-town/docs.git").Get()
-		must.True(t, has)
-		have := hosting.Detect(url, Some(configdomain.HostingPlatformBitbucketDatacenter))
-		want := Some(configdomain.HostingPlatformBitbucketDatacenter)
-		must.Eq(t, want, have)
-	})
-
-	t.Run("Gitea SAAS, no override", func(t *testing.T) {
-		t.Parallel()
-		url, has := giturl.Parse("username@gitea.com:git-town/docs.git").Get()
-		must.True(t, has)
-		have := hosting.Detect(url, None[configdomain.HostingPlatform]())
-		want := Some(configdomain.HostingPlatformGitea)
-		must.Eq(t, want, have)
-	})
-
-	t.Run("custom URL, override to Gitea", func(t *testing.T) {
-		t.Parallel()
-		url, has := giturl.Parse("username@custom.org:git-town/docs.git").Get()
-		must.True(t, has)
-		have := hosting.Detect(url, Some(configdomain.HostingPlatformGitea))
-		want := Some(configdomain.HostingPlatformGitea)
-		must.Eq(t, want, have)
-	})
-
 	t.Run("GitHub SAAS, no override", func(t *testing.T) {
 		t.Parallel()
 		url, has := giturl.Parse("username@github.com:git-town/docs.git").Get()
@@ -67,15 +31,6 @@ func TestDetect(t *testing.T) {
 		must.Eq(t, want, have)
 	})
 
-	t.Run("custom URL, override to GitHub", func(t *testing.T) {
-		t.Parallel()
-		url, has := giturl.Parse("username@custom.org:git-town/docs.git").Get()
-		must.True(t, has)
-		have := hosting.Detect(url, Some(configdomain.HostingPlatformGitHub))
-		want := Some(configdomain.HostingPlatformGitHub)
-		must.Eq(t, want, have)
-	})
-
 	t.Run("GitLab SAAS, no override", func(t *testing.T) {
 		t.Parallel()
 		url, err := giturl.Parse("username@gitlab.com:git-town/docs.git").Get()
@@ -85,6 +40,42 @@ func TestDetect(t *testing.T) {
 		must.Eq(t, want, have)
 	})
 
+	t.Run("Gitea SAAS, no override", func(t *testing.T) {
+		t.Parallel()
+		url, has := giturl.Parse("username@gitea.com:git-town/docs.git").Get()
+		must.True(t, has)
+		have := hosting.Detect(url, None[configdomain.HostingPlatform]())
+		want := Some(configdomain.HostingPlatformGitea)
+		must.Eq(t, want, have)
+	})
+
+	t.Run("custom URL, override to BitBucket", func(t *testing.T) {
+		t.Parallel()
+		url, has := giturl.Parse("username@custom.org:git-town/docs.git").Get()
+		must.True(t, has)
+		have := hosting.Detect(url, Some(configdomain.HostingPlatformBitbucket))
+		want := Some(configdomain.HostingPlatformBitbucket)
+		must.Eq(t, want, have)
+	})
+
+	t.Run("custom URL, override to Bitbucket Data Center", func(t *testing.T) {
+		t.Parallel()
+		url, has := giturl.Parse("username@custom.org:git-town/docs.git").Get()
+		must.True(t, has)
+		have := hosting.Detect(url, Some(configdomain.HostingPlatformBitbucketDatacenter))
+		want := Some(configdomain.HostingPlatformBitbucketDatacenter)
+		must.Eq(t, want, have)
+	})
+
+	t.Run("custom URL, override to GitHub", func(t *testing.T) {
+		t.Parallel()
+		url, has := giturl.Parse("username@custom.org:git-town/docs.git").Get()
+		must.True(t, has)
+		have := hosting.Detect(url, Some(configdomain.HostingPlatformGitHub))
+		want := Some(configdomain.HostingPlatformGitHub)
+		must.Eq(t, want, have)
+	})
+
 	t.Run("custom URL, override to GitLab", func(t *testing.T) {
 		t.Parallel()
 		url, err := giturl.Parse("username@custom.org:git-town/docs.git").Get()
@@ -93,4 +84,13 @@ func TestDetect(t *testing.T) {
 		want := Some(configdomain.HostingPlatformGitLab)
 		must.Eq(t, want, have)
 	})
+
+	t.Run("custom URL, override to Gitea", func(t *testing.T) {
+		t.Parallel()
+		url, has := giturl.Parse("username@custom.org:git-town/docs.git").Get()
+		must.True(t, has)
+		have := hosting.Detect(url, Some(configdomain.HostingPlatformGitea))
+		want := Some(configdomain.HostingPlatformGitea)
+		must.Eq(t, want, have)
+	})
 }
