@@ -37,6 +37,7 @@ const (
 	CodeHosting                        = "Code hosting: %s\n"
 	CommandsRun                        = "Ran %d shell commands."
 	CommitMessageProblem               = "cannot determine last commit message: %w"
+	CommitsSelected                    = "%d commits selected"
 	CompressUnsynced                   = "please sync branch %q before compressing it"
 	CompressIsPerennial                = "better not compress perennial branches"
 	CompressAlreadyOneCommit           = "branch %q has already just one commit"
@@ -47,6 +48,7 @@ const (
 	CompressObservedBranch             = "you are merely observing branch %q and should leave compressing it to the branch owner"
 	CompressParkedBranch               = "branch %q and should not compress it"
 	CompletionTypeUnknown              = "unknown completion type: %q"
+	ConfigBranchTypeOverrideEmpty      = "removing empty branch type entry"
 	ConfigFileCannotRead               = "cannot read the configuration file %q: %w"
 	ConfigFileInvalidContent           = "the configuration file %q does not contain TOML-formatted content: %w"
 	ConfigLineageParentIsChild         = "removing lineage entry for %q because the parent is the child"
@@ -116,7 +118,7 @@ END OUTPUT FROM 'git branch -vva'
 	HackBranchIsAlreadyFeature          = "branch %q is already a feature branch"
 	HackBranchIsNowFeature              = "branch %q is now a feature branch\n"
 	HackCannotFeatureMainBranch         = "you are trying to convert the main branch to a feature branch. That's not possible. If you want to create a feature branch, did you forget to add the branch name?"
-	HackCannotFeaturePerennialBranch    = "branch %q is a perennial branch and therefore be a feature branch"
+	HackCannotFeaturePerennialBranch    = "branch %q is a perennial branch and cannot be a feature branch"
 	HostingBitbucketNotImplemented      = "shipping pull requests via the Bitbucket API is currently not supported. If you need this functionality, please vote for it by opening a ticket at https://github.com/git-town/git-town/issues"
 	HostingBitbucketMergingViaAPI       = "Bitbucket API: merging PR %s ... "
 	HostingGitlabMergingViaAPI          = "Merging MR !%d ... "
@@ -143,6 +145,7 @@ END OUTPUT FROM 'git branch -vva'
 	MergeOpenChanges                      = "please commit or remove the open changes first"
 	MergeNoGrandParent                    = "cannot merge branch %q because its parent branch (%s) has no parent"
 	MergeNoParent                         = "cannot merge branch %q because it has no parent"
+	MergeWrongBranchType                  = "cannot merge %s branches"
 	ObservedBranchCannotPark              = "cannot park observed branches"
 	ObservedBranchCannotPropose           = "cannot propose observed branches"
 	ObservedBranchCannotShip              = "cannot ship observed branches"
@@ -188,69 +191,71 @@ and will be removed in future versions of Git Town.`
 
 This command has been renamed to "git town rename"
 and will be removed in future versions of Git Town.`
-	RenameNotInSync               = "%q is not in sync with its tracking branch, please sync the branches before renaming"
-	RenameMainBranch              = "the main branch cannot be renamed"
-	RenamePerennialBranchWarning  = "%q is a perennial branch. Renaming a perennial branch typically requires other updates. If you are sure you want to do this, use '--force'"
-	RenameToSameName              = "cannot rename branch to current name"
-	RepoOutside                   = "this is not a Git repository"
-	RunAutoUndo                   = "%s\nAuto-undo... "
-	RunCommandProblem             = "error running command %q: %w"
-	RunstateDeleted               = "Runstate file deleted."
-	RunstateDeleteProblem         = "cannot delete previous run state: %w"
-	RunstateLoadProblem           = "cannot load previous run state: %w"
-	RunstateSerializeProblem      = "cannot encode run-state: %w"
-	RunstatePathProblem           = "cannot determine the runstate file path: %w"
-	RunstateSaveProblem           = "cannot save run state: %w"
-	SetParentNoFeatureBranch      = "the branch %q is not a feature branch. Only feature branches can have parent branches"
-	SettingDeprecatedMessage      = "Upgrading deprecated %s setting %q to %q."
-	SettingDeprecatedValueMessage = "Upgrading value of %s Git alias %q from %q to %q."
-	SettingCannotRemove           = "ERROR: cannot remove %s Git setting %q: %v"
-	SettingCannotWrite            = "ERROR: cannot write %s Git setting %q: %v"
-	SettingIgnoreInvalid          = "Notice: ignoring invalid dialog input setting %q\n"
-	SettingSunsetDeleted          = "Deleting obsolete setting %q"
-	ShipBranchIsInOtherWorktree   = "branch %q is checked out in another worktree, please ship from there"
-	ShipBranchNotInSync           = "branch %q is not in sync"
-	ShipAbortedMergeError         = "aborted because merge exited with error"
-	ShipAPIConnectorRequired      = "please configure API access to your hosting platform, more info at https://www.git-town.com/configuration#access-tokens"
-	ShipAPIConnectorUnsupported   = "the Git Town driver for your code hosting platform does not support shipping via the API"
-	ShipBranchOtherWorktree       = "branch %q is active in another worktree"
-	ShipBranchHasNoParent         = "branch %q has no parent to ship into"
-	ShipBranchNothingToDo         = "the branch %q has no shippable changes"
-	ShipChildBranch               = "shipping this branch would ship %s as well,\nplease ship %q first"
-	ShipDeletesTrackingBranches   = "Ship deletes tracking branches: %s\n"
-	ShipAPINoProposal             = "cannot ship branch %q via API because it has no proposal"
-	ShipAPINoRemoteBranch         = "cannot ship branch %q via API because it has no remote branch"
-	ShipMessageWithFastForward    = "shipping with the fast-forward strategy does not use the given commit message"
-	ShipOpenChanges               = "you have uncommitted changes. Did you mean to commit them before shipping?"
-	ShipStrategyMissing           = "no ship strategy provided"
-	ShippableChangesProblem       = "cannot determine whether branch %q has shippable changes: %w"
-	SkipBranchHasConflicts        = "cannot skip branch that resulted in conflicts"
-	SkipMessage                   = `You can run "git town skip" to skip the currently failing operation.`
-	SkipNothingToDo               = "nothing to skip"
-	SkipNoInitialBranchInfo       = "found no information about branch %q in the initial snapshot"
-	SkipNoFinalBranchInfo         = "found no information about branch %q in the final snapshot"
-	SkipNoFinalSnapshot           = "found no final snapshot"
-	SquashCannotReadFile          = "cannot read squash message file %q: %w"
-	SquashCommitAuthorQuery       = "Please choose an author for the squash commit:"
-	SquashCommitAuthorProblem     = "error getting squash commit author: %w"
-	SquashCommitAuthorSelection   = "Selected squash commit author: %s\n"
-	SquashMessageProblem          = "cannot comment out the squash commit message: %w"
-	StatusFileNotFound            = "No status file found for this repository."
-	SwitchNoBranches              = "no branches to switch to"
-	SwitchUncommittedChanges      = "uncommitted changes"
-	SyncFeatureBranches           = "Sync feature branches: %s\n"
-	SyncPerennialBranches         = "Sync perennial branches: %s\n"
-	SyncPrototypeBranches         = "Sync prototype branches: %s\n"
-	SyncStatusNotRecognized       = "cannot determine the sync status for Git remote %q and branch name %q"
-	SyncTags                      = "Sync tags: %s\n"
-	SyncWithUpstream              = "Sync with upstream: %s\n"
-	UndoCreateOpcodeProblem       = "cannot create undo operations for %q: %w"
-	UndoMessage                   = `You can run "git town undo" to go back to where you started.`
-	UndoNothingToDo               = "nothing to undo"
-	UnfinishedCommandHandle       = "Handle unfinished command: %s\n"
-	UnfinishedRunStateContinue    = "Continue the \"%s\" command after having resolved conflicts"
-	UnfinishedRunStateDiscard     = "Discard the unfinished state and run the new command"
-	UnfinishedRunStateQuit        = "Quit without running anything"
-	UnfinishedRunStateSkip        = "Skip the current branch and continue the \"%s\" command on the next branch"
-	UnfinishedRunStateUndo        = "Undo the previous \"%s\" command"
+	RenameNotInSync                         = "%q is not in sync with its tracking branch, please sync the branches before renaming"
+	RenameMainBranch                        = "the main branch cannot be renamed"
+	RenamePerennialBranchWarning            = "%q is a perennial branch. Renaming a perennial branch typically requires other updates. If you are sure you want to do this, use '--force'"
+	RenameToSameName                        = "cannot rename branch to current name"
+	RepoOutside                             = "this is not a Git repository"
+	RunAutoUndo                             = "%s\nAuto-undo... "
+	RunCommandProblem                       = "error running command %q: %w"
+	RunstateDeleted                         = "Runstate file deleted."
+	RunstateDeleteProblem                   = "cannot delete previous run state: %w"
+	RunstateLoadProblem                     = "cannot load previous run state: %w"
+	RunstateSerializeProblem                = "cannot encode run-state: %w"
+	RunstatePathProblem                     = "cannot determine the runstate file path: %w"
+	RunstateSaveProblem                     = "cannot save run state: %w"
+	SetParentNoFeatureBranch                = "the branch %q is not a feature branch. Only feature branches can have parent branches"
+	SettingDeprecatedMessage                = "Upgrading deprecated %s setting %q to %q."
+	SettingDeprecatedValueMessage           = "Upgrading value of %s Git alias %q from %q to %q."
+	SettingCannotRemove                     = "ERROR: cannot remove %s Git setting %q: %v"
+	SettingCannotWrite                      = "ERROR: cannot write %s Git setting %q: %v"
+	SettingIgnoreInvalid                    = "Notice: ignoring invalid dialog input setting %q\n"
+	SettingSunsetDeleted                    = "Deleting obsolete setting %q"
+	ShipBranchIsInOtherWorktree             = "branch %q is checked out in another worktree, please ship from there"
+	ShipBranchNotInSync                     = "branch %q is not in sync"
+	ShipAbortedMergeError                   = "aborted because merge exited with error"
+	ShipAPIConnectorRequired                = "please configure API access to your hosting platform, more info at https://www.git-town.com/configuration#access-tokens"
+	ShipAPIConnectorUnsupported             = "the Git Town driver for your code hosting platform does not support shipping via the API"
+	ShipBranchOtherWorktree                 = "branch %q is active in another worktree"
+	ShipBranchHasNoParent                   = "branch %q has no parent to ship into"
+	ShipBranchNothingToDo                   = "the branch %q has no shippable changes"
+	ShipChildBranch                         = "shipping this branch would ship %s as well,\nplease ship %q first"
+	ShipDeletesTrackingBranches             = "Ship deletes tracking branches: %s\n"
+	ShipAPINoProposal                       = "cannot ship branch %q via API because it has no proposal"
+	ShipAPINoRemoteBranch                   = "cannot ship branch %q via API because it has no remote branch"
+	ShipMessageWithFastForward              = "shipping with the fast-forward strategy does not use the given commit message"
+	ShipOpenChanges                         = "you have uncommitted changes. Did you mean to commit them before shipping?"
+	ShipStrategyMissing                     = "no ship strategy provided"
+	ShippableChangesProblem                 = "cannot determine whether branch %q has shippable changes: %w"
+	SkipBranchHasConflicts                  = "cannot skip branch that resulted in conflicts"
+	SkipMessage                             = `You can run "git town skip" to skip the currently failing operation.`
+	SkipNothingToDo                         = "nothing to skip"
+	SkipNoInitialBranchInfo                 = "found no information about branch %q in the initial snapshot"
+	SkipNoFinalBranchInfo                   = "found no information about branch %q in the final snapshot"
+	SkipNoFinalSnapshot                     = "found no final snapshot"
+	SquashCannotReadFile                    = "cannot read squash message file %q: %w"
+	SquashCommitAuthorQuery                 = "Please choose an author for the squash commit:"
+	SquashCommitAuthorProblem               = "error getting squash commit author: %w"
+	SquashCommitAuthorSelection             = "Selected squash commit author: %s\n"
+	SquashMessageProblem                    = "cannot comment out the squash commit message: %w"
+	StatusFileNotFound                      = "No status file found for this repository."
+	SwitchNoBranches                        = "no branches to switch to"
+	SwitchUncommittedChanges                = "uncommitted changes"
+	SyncFeatureBranches                     = "Sync feature branches: %s\n"
+	SyncPerennialBranchHasUnpushedCommits   = `cannot sync branch %q because it has unpushed local commits`
+	SyncPerennialBranches                   = "Sync perennial branches: %s\n"
+	SyncPrototypeBranches                   = "Sync prototype branches: %s\n"
+	SyncStatusNotRecognized                 = "cannot determine the sync status for Git remote %q and branch name %q"
+	SyncTags                                = "Sync tags: %s\n"
+	SyncWithUpstream                        = "Sync with upstream: %s\n"
+	UndoCannotRevertCommitOnPerennialBranch = "Cannot undo commit %q because it is on a perennial branch"
+	UndoCreateOpcodeProblem                 = "cannot create undo operations for %q: %w"
+	UndoMessage                             = `You can run "git town undo" to go back to where you started.`
+	UndoNothingToDo                         = "nothing to undo"
+	UnfinishedCommandHandle                 = "Handle unfinished command: %s\n"
+	UnfinishedRunStateContinue              = "Continue the \"%s\" command after having resolved conflicts"
+	UnfinishedRunStateDiscard               = "Discard the unfinished state and run the new command"
+	UnfinishedRunStateQuit                  = "Quit without running anything"
+	UnfinishedRunStateSkip                  = "Skip the current branch and continue the \"%s\" command on the next branch"
+	UnfinishedRunStateUndo                  = "Undo the previous \"%s\" command"
 )
