@@ -1,15 +1,17 @@
 package undobranches
 
 import (
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/undo/undodomain"
-	"golang.org/x/exp/maps"
+	"maps"
+	"slices"
+
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/undo/undodomain"
 )
 
 type RemoteBranchChange map[gitdomain.RemoteBranchName]undodomain.Change[gitdomain.SHA]
 
 func (self RemoteBranchChange) BranchNames() gitdomain.RemoteBranchNames {
-	result := gitdomain.RemoteBranchNames(maps.Keys(self))
+	result := gitdomain.RemoteBranchNames(slices.Collect(maps.Keys(self)))
 	result.Sort()
 	return result
 }
