@@ -1,15 +1,17 @@
 package undobranches
 
 import (
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"golang.org/x/exp/maps"
+	"maps"
+	"slices"
+
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
 )
 
 type RemoteBranchesSHAs map[gitdomain.RemoteBranchName]gitdomain.SHA
 
 // BranchNames provides the names of the involved branches as strings.
 func (self RemoteBranchesSHAs) BranchNames() gitdomain.RemoteBranchNames {
-	result := gitdomain.RemoteBranchNames(maps.Keys(self))
+	result := gitdomain.RemoteBranchNames(slices.Collect(maps.Keys(self)))
 	result.Sort()
 	return result
 }
