@@ -1,8 +1,8 @@
 package opcodes
 
 import (
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/vm/shared"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/vm/shared"
 )
 
 // PushCurrentBranchIfNeeded pushes the current branch to its existing tracking branch
@@ -20,6 +20,6 @@ func (self *PushCurrentBranchIfNeeded) Run(args shared.RunArgs) error {
 	if !shouldPush {
 		return nil
 	}
-	args.PrependOpcodes(&PushCurrentBranch{CurrentBranch: self.CurrentBranch})
+	args.PrependOpcodes(&PushCurrentBranch{})
 	return nil
 }
