@@ -4,14 +4,14 @@ import (
 	"encoding/json"
 	"fmt"
 
-	"github.com/git-town/git-town/v17/internal/gohacks"
-	"github.com/git-town/git-town/v17/internal/messages"
-	"github.com/git-town/git-town/v17/internal/vm/opcodes"
-	"github.com/git-town/git-town/v17/internal/vm/shared"
+	"github.com/git-town/git-town/v18/internal/gohacks"
+	"github.com/git-town/git-town/v18/internal/messages"
+	"github.com/git-town/git-town/v18/internal/vm/opcodes"
+	"github.com/git-town/git-town/v18/internal/vm/shared"
 )
 
 // JSON is used to store an opcode in JSON.
-type JSON struct { //nolint:musttag // JSON uses a custom serialization algorithm
+type JSON struct {
 	shared.Opcode
 }
 
