@@ -3,18 +3,17 @@ package datatable
 import (
 	"fmt"
 	"log"
+	"maps"
 	"regexp"
 	"sort"
 	"strings"
 	"sync"
 
 	"github.com/cucumber/godog"
-
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks/stringslice"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
+	"github.com/git-town/git-town/v18/internal/git/gitdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
 	"github.com/sergi/go-diff/diffmatchpatch"
-	"golang.org/x/exp/maps"
 )
 
 // DataTable allows comparing user-generated data with Gherkin tables.
@@ -24,6 +23,10 @@ type DataTable struct {
 	Cells [][]string `exhaustruct:"optional"`
 }
 
+type runner interface {
+	SHAsForCommit(name string) gitdomain.SHAs
+}
+
 // FromGherkin provides a DataTable instance populated with data from the given Gherkin table.
 func FromGherkin(table *godog.Table) DataTable {
 	result := DataTable{}
@@ -98,7 +101,7 @@ func (self *DataTable) Expand(localRepo runner, remoteRepo runner, worktreeRepo
 					if !found {
 						fmt.Printf("I cannot find the initial dev commit %q.\n", commitName)
 						fmt.Printf("I have records about %d commits:\n", len(initialDevSHAs))
-						for _, key := range maps.Keys(initialDevSHAs) {
+						for key := range maps.Keys(initialDevSHAs) {
 							fmt.Println("  -", key)
 						}
 						panic("see error above")
@@ -114,7 +117,7 @@ func (self *DataTable) Expand(localRepo runner, remoteRepo runner, worktreeRepo
 					if !found {
 						fmt.Printf("I cannot find the initial origin commit %q.\n", commitName)
 						fmt.Printf("I have records about %d commits:\n", len(initialOriginSHAs))
-						for _, key := range maps.Keys(initialOriginSHAs) {
+						for key := range maps.Keys(initialOriginSHAs) {
 							fmt.Println("  -", key)
 						}
 					}
@@ -134,7 +137,7 @@ func (self *DataTable) Expand(localRepo runner, remoteRepo runner, worktreeRepo
 					if !found {
 						fmt.Printf("I cannot find the initial worktree commit %q.\n", commitName)
 						fmt.Printf("I have records about %d commits:\n", len(initialWorktreeSHAs))
-						for _, key := range maps.Keys(initialWorktreeSHAs) {
+						for key := range maps.Keys(initialWorktreeSHAs) {
 							fmt.Println("  -", key)
 						}
 					}
