@@ -4,9 +4,8 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/git-town/git-town/v17/internal/git/gitdomain"
-	"github.com/git-town/git-town/v17/test/asserts"
-	"github.com/git-town/git-town/v17/test/fixture"
+	"github.com/git-town/git-town/v18/test/asserts"
+	"github.com/git-town/git-town/v18/test/fixture"
 	"github.com/shoenig/test/must"
 )
 
@@ -19,11 +18,11 @@ func TestNewStandardFixture(t *testing.T) {
 	asserts.IsGitRepo(t, filepath.Join(gitEnvRootDir, "origin"))
 	branch, err := result.OriginRepo.GetOrPanic().CurrentBranch(devRepo.TestRunner)
 	must.NoError(t, err)
-	must.EqOp(t, gitdomain.NewLocalBranchName("main"), branch)
+	must.EqOp(t, "main", branch)
 	// verify the developer repo
 	asserts.IsGitRepo(t, filepath.Join(gitEnvRootDir, "developer"))
 	assertHasGitConfiguration(t, gitEnvRootDir)
 	branch, err = devRepo.CurrentBranch(devRepo.TestRunner)
 	must.NoError(t, err)
-	must.EqOp(t, gitdomain.NewLocalBranchName("main"), branch)
+	must.EqOp(t, "main", branch)
 }
