@@ -12,8 +12,8 @@ type AtomicCounter struct {
 	value uint32
 }
 
-// ToString provides a globally unique text each time it is called.
-func (self *AtomicCounter) ToString() string {
+// NextAsString provides a globally unique text each time it is called.
+func (self *AtomicCounter) NextAsString() string {
 	atomic.AddUint32(&self.value, 1)
 	return strconv.FormatUint(uint64(self.value), 10)
 }
