@@ -5,26 +5,25 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"log"
 	"os"
 	"os/exec"
 	"path/filepath"
 	"runtime"
 	"strings"
 
-	"github.com/git-town/git-town/v17/internal/config/configdomain"
-	"github.com/git-town/git-town/v17/internal/gohacks/stringslice"
-	"github.com/git-town/git-town/v17/internal/hosting/hostingdomain"
-	"github.com/git-town/git-town/v17/internal/subshell"
-	. "github.com/git-town/git-town/v17/pkg/prelude"
-	"github.com/git-town/git-town/v17/test/asserts"
-	"github.com/git-town/git-town/v17/test/envvars"
+	"github.com/git-town/git-town/v18/internal/config/configdomain"
+	"github.com/git-town/git-town/v18/internal/gohacks/stringslice"
+	"github.com/git-town/git-town/v18/internal/hosting/hostingdomain"
+	"github.com/git-town/git-town/v18/internal/subshell"
+	. "github.com/git-town/git-town/v18/pkg/prelude"
+	"github.com/git-town/git-town/v18/test/asserts"
+	"github.com/git-town/git-town/v18/test/envvars"
 	"github.com/kballard/go-shellquote"
 )
 
 // TestRunner runs shell commands using a customizable environment.
 // This is useful in tests. Possible customizations:
-//   - overide environment variables
+//   - override environment variables
 //   - Temporarily override certain shell commands with mock implementations.
 //     Temporary mocks are only valid for the next command being run.
 type TestRunner struct {
@@ -96,9 +95,7 @@ else
 	%s "$@"
 fi`
 	gitPath, err := exec.LookPath("git")
-	if err != nil {
-		log.Fatalf("cannot locate the git executable: %v", err)
-	}
+	asserts.NoError(err)
 	content := fmt.Sprintf(mockGit, version, gitPath)
 	self.createMockBinary("git", content)
 }
@@ -193,6 +190,7 @@ func (self *TestRunner) QueryWithCode(opts *Options, cmd string, args ...string)
 	}
 	// set HOME to the given global directory so that Git puts the global configuration there.
 	opts.Env = envvars.Replace(opts.Env, "HOME", self.HomeDir)
+	opts.Env = append(opts.Env, `GIT_CONFIG_PARAMETERS='core.abbrev=40'`)
 	// add the custom origin
 	if testOrigin, hasTestOrigin := self.testOrigin.Get(); hasTestOrigin {
 		opts.Env = envvars.Replace(opts.Env, "GIT_TOWN_REMOTE", testOrigin)
@@ -220,7 +218,6 @@ func (self *TestRunner) QueryWithCode(opts *Options, cmd string, args ...string)
 	}
 	var outputBuf bytes.Buffer
 	subProcess.Stdout = &outputBuf
-	subProcess.Stderr = &outputBuf
 	if input, hasInput := opts.Input.Get(); hasInput {
 		var stdin io.WriteCloser
 		stdin, err = subProcess.StdinPipe()
