@@ -5,8 +5,8 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/git-town/git-town/v17/test/ostools"
-	"github.com/git-town/git-town/v17/test/subshell"
+	"github.com/git-town/git-town/v18/test/ostools"
+	"github.com/git-town/git-town/v18/test/subshell"
 	"github.com/shoenig/test/must"
 )
 
@@ -32,16 +32,26 @@ func TestMockingRunner(t *testing.T) {
 		must.EqOp(t, "foo called with: bar", res)
 	})
 
-	t.Run("Run", func(t *testing.T) {
+	t.Run("MockCommitMessage", func(t *testing.T) {
 		t.Parallel()
+		dir := t.TempDir()
 		runner := subshell.TestRunner{
-			WorkingDir: t.TempDir(),
-			HomeDir:    t.TempDir(),
-			BinDir:     "",
+			WorkingDir: dir,
+			HomeDir:    dir,
+			BinDir:     filepath.Join(dir, "bin"),
 		}
-		res, err := runner.Query("echo", "hello", "world")
+		runner.MockCommitMessage("test commit message")
+		// Simulate Git calling the mock editor configured by MockCommitMessage and
+		// verify its effect.
+		// MockCommitMessage creates a custom editor that the runner makes available
+		// via the GIT_EDITOR environment variable. We verify the following:
+		// - GIT_EDITOR is available and executable.
+		// - The contents of the file provided in the first argument to $GIT_EDITOR
+		//   our expected commit message after the command has finished.
+		_ = runner.MustQuery("bash", "-c", `"$GIT_EDITOR" output`)
+		data, err := os.ReadFile(filepath.Join(dir, "output"))
 		must.NoError(t, err)
-		must.EqOp(t, "hello world", res)
+		must.Eq(t, "test commit message\n", string(data))
 	})
 
 	t.Run("QueryString", func(t *testing.T) {
@@ -105,4 +115,16 @@ func TestMockingRunner(t *testing.T) {
 			must.NoError(t, err)
 		})
 	})
+
+	t.Run("Run", func(t *testing.T) {
+		t.Parallel()
+		runner := subshell.TestRunner{
+			WorkingDir: t.TempDir(),
+			HomeDir:    t.TempDir(),
+			BinDir:     "",
+		}
+		res, err := runner.Query("echo", "hello", "world")
+		must.NoError(t, err)
+		must.EqOp(t, "hello world", res)
+	})
 }
